@@ -15,14 +15,14 @@ class ActivationsAndGradients:
         activation = output
         if self.reshape_transform is not None:
             activation = self.reshape_transform(activation)
-        self.activations.append(activation.cpu())
+        self.activations.append(activation.cpu().detach())
 
     def save_gradient(self, module, grad_input, grad_output):
         # Gradients are computed in reverse order
         grad = grad_output[0]
         if self.reshape_transform is not None:
             grad = self.reshape_transform(grad)
-        self.gradients = [grad.cpu()] + self.gradients
+        self.gradients = [grad.cpu().detach()] + self.gradients
 
     def __call__(self, x):
         self.gradients = []
