@@ -16,14 +16,14 @@ class GradCAMPlusPlus(BaseCAM):
         grads_power_2 = grads**2
         grads_power_3 = grads_power_2*grads
         # Equation 19 in https://arxiv.org/abs/1710.11063
-        sum_activations = np.sum(activations, axis=(1, 2))
+        sum_activations = np.sum(activations, axis=(2, 3))
         eps = 0.000001
-        aij = grads_power_2 / (2*grads_power_2 + sum_activations[:, None, None]*grads_power_3 + eps)
-
+        aij = grads_power_2 / (2*grads_power_2 + 
+            sum_activations[:, :, None, None]*grads_power_3 + eps)
         # Now bring back the ReLU from eq.7 in the paper,
         # And zero out aijs where the activations are 0
         aij = np.where(grads != 0, aij, 0)
 
         weights = np.maximum(grads, 0)*aij
-        weights = np.sum(weights, axis=(1, 2))
+        weights = np.sum(weights, axis=(2, 3))
         return weights
\ No newline at end of file
